@@ -145,6 +145,7 @@ class PyMongo(object):
             app.config[key('USERNAME')] = parsed['username']
             app.config[key('PASSWORD')] = parsed['password']
             app.config[key('REPLICA_SET')] = parsed['options'].get('replica_set')
+            app.config[key('MAX_POOL_SIZE')] = parsed['options'].get('max_pool_size')
 
             # we will use the URI for connecting instead of HOST/PORT
             app.config.pop(key('HOST'), None)
@@ -162,6 +163,7 @@ class PyMongo(object):
             app.config.setdefault(key('USERNAME'), None)
             app.config.setdefault(key('PASSWORD'), None)
             app.config.setdefault(key('REPLICA_SET'), None)
+            app.config.setdefault(key('MAX_POOL_SIZE'), None)
 
             try:
                 port = int(app.config[key('PORT')])
@@ -187,6 +189,8 @@ class PyMongo(object):
         replica_set = app.config[key('REPLICA_SET')]
         dbname = app.config[key('DBNAME')]
         auto_start_request = app.config[key('AUTO_START_REQUEST')]
+        max_pool_size = app.config[key('MAX_POOL_SIZE')]
+
         if auto_start_request not in (True, False):
             raise TypeError('%s_AUTO_START_REQUEST must be a bool' % config_prefix)
 
@@ -215,6 +219,9 @@ class PyMongo(object):
                     return response
                 app.after_request(call_end_request)
 
+        if max_pool_size is not None:
+            kwargs['max_pool_size'] = max_pool_size
+
         cx = connection_cls(*args, **kwargs)
         db = cx[dbname]
 
